/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2010-2012 University of Bonn. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * CalculateBoundingBoxAction.cpp
 *
 *  Created on: Nov 02, 2011
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "CodePatterns/Log.hpp"

#include "Box.hpp"
#include "CodePatterns/Assert.hpp"
#include "LinearAlgebra/Plane.hpp"
#include <vector>
#include <utility>
#include "World.hpp"

#include <iostream>
#include <string>

#include "CalculateBoundingBoxAction.hpp"

using namespace MoleCuilder;

// and construct the stuff
#include "CalculateBoundingBoxAction.def"
#include "Reaction_impl_pre.hpp"

#include "Reaction_impl.hpp"

/** =========== define the function ====================== */
doubleVec * AnalysisCalculateBoundingBoxAction::doCalc() {
  typedef std::pair<Plane,Plane> PairOfPlanes;
  typedef std::vector<PairOfPlanes> PairOfPlanesVector;
  const PairOfPlanesVector planes = World::getInstance().getDomain().getBoundingPlanes();
  doubleVec returnvalues;
  for (PairOfPlanesVector::const_iterator iter = planes.begin();
    iter != planes.end(); ++iter) {
    returnvalues.push_back(fabs(iter->first.getOffset()));
    returnvalues.push_back(fabs(iter->second.getOffset()));
  }
  ASSERT( returnvalues.size() == (size_t)6,
      "AnalysisCalculateBoundingBoxAction::doCalc() - returnvalues should be of length 6 but is "
      +toString(returnvalues.size())+".");

  LOG(0, "RESULT: The current bounding box is " << returnvalues << ".");

  return (new doubleVec(returnvalues));
}
/** =========== end of function ====================== */
